diff --git a/configure.ac b/configure.ac
index b4b788708c..58ab9ae2f9 100644
--- a/configure.ac
+++ b/configure.ac
@@ -4846,16 +4846,16 @@ AS_HELP_STRING([--disable-websockets],[Disable WebSockets support]),
if test ${ac_cv_sizeof_curl_off_t} -gt 4; then
AC_MSG_RESULT(yes)
curl_ws_msg="enabled"
- AC_DEFINE_UNQUOTED(USE_WEBSOCKETS, [1], [enable websockets support])
+ AC_DEFINE_UNQUOTED(USE_WEBSOCKETS, [1], [enable WebSockets support])
SUPPORT_PROTOCOLS="$SUPPORT_PROTOCOLS WS"
if test "x$SSL_ENABLED" = "x1"; then
SUPPORT_PROTOCOLS="$SUPPORT_PROTOCOLS WSS"
fi
- experimental="$experimental Websockets"
+ experimental="$experimental WebSockets"
else
- dnl websockets requires >32 bit curl_off_t
+ dnl WebSockets requires >32 bit curl_off_t
AC_MSG_RESULT(no)
- AC_MSG_WARN([Websockets disabled due to lack of >32 bit curl_off_t])
+ AC_MSG_WARN([WebSockets disabled due to lack of >32 bit curl_off_t])
fi
;;
esac ],
diff --git a/include/curl/curl.h b/include/curl/curl.h
index 840c2864cb..2890d05e1a 100644
--- a/include/curl/curl.h
+++ b/include/curl/curl.h
@@ -2203,7 +2203,7 @@ typedef enum {
/* specify which protocols that libcurl is allowed to follow directs to */
CURLOPT(CURLOPT_REDIR_PROTOCOLS_STR, CURLOPTTYPE_STRINGPOINT, 319),
- /* websockets options */
+ /* WebSockets options */
CURLOPT(CURLOPT_WS_OPTIONS, CURLOPTTYPE_LONG, 320),
/* CA cache timeout */
diff --git a/lib/http.c b/lib/http.c
index 6b2755d74f..687b87436c 100644
--- a/lib/http.c
+++ b/lib/http.c
@@ -3535,7 +3535,7 @@ static CURLcode http_on_response(struct Curl_easy *data,
#endif
#ifdef USE_WEBSOCKETS
- /* All >=200 HTTP status codes are errors when wanting websockets */
+ /* All >=200 HTTP status codes are errors when wanting WebSockets */
if(data->req.upgr101 == UPGR101_WS) {
failf(data, "Refused WebSockets upgrade: %d", k->httpcode);
result = CURLE_HTTP_RETURNED_ERROR;
diff --git a/lib/ws.c b/lib/ws.c
index 9f80fec9f0..c845f5d3e1 100644
--- a/lib/ws.c
+++ b/lib/ws.c
@@ -1276,7 +1276,7 @@ static void ws_free(struct connectdata *conn)
static CURLcode ws_setup_conn(struct Curl_easy *data,
struct connectdata *conn)
{
- /* websockets is 1.1 only (for now) */
+ /* WebSockets is 1.1 only (for now) */
data->state.httpwant = CURL_HTTP_VERSION_1_1;
return Curl_http_setup_conn(data, conn);
}
diff --git a/tests/http/clients/ws-pingpong.c b/tests/http/clients/ws-pingpong.c
index c86d7daed8..4b57e21e85 100644
--- a/tests/http/clients/ws-pingpong.c
+++ b/tests/http/clients/ws-pingpong.c
@@ -22,7 +22,7 @@
*
***************************************************************************/
/*
- * Websockets pingpong
+ * WebSockets pingpong
*
*/
/* curl stuff */
@@ -160,7 +160,7 @@ int main(int argc, char *argv[])
#else /* USE_WEBSOCKETS */
(void)argc;
(void)argv;
- fprintf(stderr, "websockets not enabled in libcurl\n");
+ fprintf(stderr, "WebSockets not enabled in libcurl\n");
return 1;
#endif /* !USE_WEBSOCKETS */
}
diff --git a/tests/libtest/lib2301.c b/tests/libtest/lib2301.c
index 377228ab3a..cd31207703 100644
--- a/tests/libtest/lib2301.c
+++ b/tests/libtest/lib2301.c
@@ -149,6 +149,6 @@ CURLcode test(char *URL)
return res;
}
-#else /* no websockets */
+#else /* no WebSockets */
NO_SUPPORT_BUILT_IN
#endif
diff --git a/tests/http/clients/ws-data.c b/tests/http/clients/ws-data.c
index d045c5d2cb..ee067dd96e 100644
--- a/tests/http/clients/ws-data.c
+++ b/tests/http/clients/ws-data.c
@@ -22,7 +22,7 @@
*
***************************************************************************/
/*
* Websockets data echos
*
*/
/* curl stuff */
@@ -265,7 +265,7 @@ int main(int argc, char *argv[])
#else /* USE_WEBSOCKETS */
(void)argc;
(void)argv;
- fprintf(stderr, "websockets not enabled in libcurl\n");
+ fprintf(stderr, "WebSockets not enabled in libcurl\n");
return 1;
#endif /* !USE_WEBSOCKETS */
}
@@ -22,7 +22,7 @@
***************************************************************************/
/*
- * Websockets data echos
+ * WebSockets data echos
*
*/